@@ -309,7 +309,7 @@ class Experiment(object):
     @staticmethod
     def is_valid(experiment_name):
         return (isinstance(experiment_name, basestring) and
-            VALID_EXPERIMENT_ALTERNATIVE_RE.match(experiment_name) is not None)
+                VALID_EXPERIMENT_ALTERNATIVE_RE.match(experiment_name) is not None)
 
 
 class AlternativeCollection(object):
@@ -397,7 +397,6 @@ class Alternative(object):
         except ZeroDivisionError:
             return 0
 
-    # Hacky z-score from https://github.com/andrew/split/blob/master/lib/split/alternative.rb
     def z_score(self):
 
         if self.is_control():
@@ -411,10 +410,8 @@ class Alternative(object):
         c = control.participant_count()
 
         try:
-            std_dev = pow((ctr_e*(1-ctr_e)/e + ctr_c*(1-ctr_c)/c),.5)
+            std_dev = pow((ctr_e * (1 - ctr_e) / e + ctr_c * (1 - ctr_c) / c), .5)
             return (ctr_e - ctr_c) / std_dev
-            # old std dev
-            # std_dev = pow(((ctr_e / pow(ctr_c, 3)) * ((e*ctr_e)+(c*ctr_c)-(ctr_c*ctr_e)*(c+e))/(c*e)), 0.5)
         except ZeroDivisionError:
             return 0
 
@@ -442,11 +439,7 @@ class Alternative(object):
     def key(self):
         return _key("{0}:{1}".format(self.experiment_name, self.name))
 
-    @staticmethod
-    def number_to_percent(number, precision=2):
-        return round(number * 100, precision)
-
     @staticmethod
     def is_valid(alternative_name):
         return (isinstance(alternative_name, basestring) and
-            VALID_EXPERIMENT_ALTERNATIVE_RE.match(alternative_name) is not None)
+                VALID_EXPERIMENT_ALTERNATIVE_RE.match(alternative_name) is not None)
